@@ -10,7 +10,7 @@
 # ABSTRACT: Check the configuration of an application
 
 package App::Cme::Command::check ;
-$App::Cme::Command::check::VERSION = '1.014';
+$App::Cme::Command::check::VERSION = '1.016';
 use strict;
 use warnings;
 use 5.10.1;
@@ -29,6 +29,7 @@ sub opt_spec {
     my ( $class, $app ) = @_;
     return ( 
         [ "strict!" => "cme will exit 1 if warnings are found during check" ],
+        [ "quiet!"  => "Suppress progress messages" ],
         $class->cme_global_options,
     );
 }
@@ -48,9 +49,14 @@ sub execute {
     my ($self, $opt, $args) = @_;
 
     my ($model, $inst, $root) = $self->init_cme($opt,$args);
-
+    my $check =  $opt->{force_load} ? 'no' : 'yes' ;
     say "loading data" unless $opt->{quiet};
-    Config::Model::ObjTreeScanner->new( leaf_cb => sub { } )->scan_node( undef, $root );
+
+    Config::Model::ObjTreeScanner->new(
+        leaf_cb => sub { },
+        check => $check,
+    )->scan_node( undef, $root );
+
     say "checking data" unless $opt->{quiet};
     $root->dump_tree( mode => 'full' ); # light check (value per value)
     $root->deep_check; # consistency check
@@ -79,7 +85,7 @@ App::Cme::Command::check - Check the configuration of an application
 
 =head1 VERSION
 
-version 1.014
+version 1.016
 
 =head1 SYNOPSIS
 
